pub struct FeatureMappings {
pub sml: ModuleFeatures,
pub wml: ModuleFeatures,
pub pml: ModuleFeatures,
pub dml: ModuleFeatures,
}Expand description
Complete feature mappings file structure.
Fields
sml: ModuleFeaturesSpreadsheetML feature mappings.
wml: ModuleFeaturesWordprocessingML feature mappings.
pml: ModuleFeaturesPresentationML feature mappings.
dml: ModuleFeaturesDrawingML feature mappings.
Implementations
Sourceimpl FeatureMappings
impl FeatureMappings
Sourcepub fn from_yaml_file(path: &Path) -> Result<Self, Box<dyn Error>>
pub fn from_yaml_file(path: &Path) -> Result<Self, Box<dyn Error>>
Load mappings from a YAML file.
Sourcepub fn for_module(&self, module: &str) -> &ModuleFeatures
pub fn for_module(&self, module: &str) -> &ModuleFeatures
Get the module features for a given module name.
Get feature tags for a specific element’s attribute/child.
Returns None if no mapping exists (meaning it’s always included).
Supports * wildcard as a fallback for fields not explicitly listed.